import AesCipherInstance from '@/utils/encrypt/encrypt.ts'
interface UserInfo {
  userName: string
  isSuper: boolean
}

/**
 * 从localstorage获取数据
 * @param {string} name localstorage的key
 * @param {string} prop 属性名，不传就返回整个对象
 */
const getLocalInfo = (name: string, prop?: string): string | string[] => {
  const info = localStorage.getItem(name)
  let result = ''
  if (info) {
    const jsonInfo = JSON.parse(info)

    if (prop) result = jsonInfo[prop]
    else result = jsonInfo
  }

  return result
}

/**
 * 保存到本地
 * @param {string} name localstorage的key
 * @param {any} value 值
 * @param {string} prop 属性名
 */
const saveLocalInfo = (name: string, value: any, prop?: string) => {
  const info = localStorage.getItem(name)
  if (info) {
    const jsonInfo = JSON.parse(info)
    if (prop) jsonInfo[prop] = value
    localStorage.setItem(name, JSON.stringify(jsonInfo))
  } else {
    localStorage.setItem(name, JSON.stringify(value))
  }
}

/**
 * 设置登陆状态
 * @param {boolean} state 登录状态
 */
const setLoginState = (state: boolean) => {
  localStorage.setItem('loginState', JSON.stringify(state))
}

/**
 * 获取当前登录状态
 */
const getLoginState = (): boolean => {
  return JSON.parse(localStorage.getItem('loginState') as string) as boolean
}

/**
 * 清除用户信息
 */
const clearUserInfo = () => {
  localStorage.removeItem('userInfo')
}

/**
 * 保存用户信息
 * @param userInfo 用户信息
 */
const setUserInfo = (userInfo: any) => {
  const encryptInfo = AesCipherInstance.encrypt(JSON.stringify(userInfo))
  localStorage.setItem('userInfo', encryptInfo)
}

/**
 * 获取用户信息
 */
const getUserInfo = (): UserInfo | null => {
  const info = localStorage.getItem('userInfo')
  if (info) {
    const decryptInfo = AesCipherInstance.decrypt(info)
    return JSON.parse(decryptInfo) as UserInfo
  }
  return null
}

export {
  getLocalInfo,
  saveLocalInfo,
  setLoginState,
  getLoginState,
  setUserInfo,
  getUserInfo,
  clearUserInfo
}
